TADS Runner
===========

This repository contains an open source for of the [TADS Runner](https://www.tads.org/index.htm). While the original TADS code is not under a FLOSS license, permission was given for Gargyole to include TADS under the GPL-2.0 license. This repository was extracted from the [garglk repository](https://github.com/garglk/garglk), so that other interpreters may more easily use its FLOSS code. The focus is on the Glk port (GlkTADS), but changes relevant to non-Glk interpreters are welcome too. Some bugs have been fixed here that are not fixed in the official TADS interpreter.

For discussion about this version of the TADS Runner, please visit the [IntFiction forum](https://intfiction.org/).